@@ -206,6 +206,8 @@ SV *Py2Pl(PyObject * const obj) {
                 SvUTF8_on(utf8_key);
 
                 hv_store_ent(retval, utf8_key, sv_val, 0);
+
+                sv_2mortal(utf8_key);
                 Py_DECREF(utf8_string);
             }
             else {
@@ -232,7 +234,6 @@ SV *Py2Pl(PyObject * const obj) {
 #else
                     key_val = PyString_AsString(s);
 #endif
-                    Py_DECREF(s);
                     if (PL_dowarn)
                         warn("Stringifying non-string hash key value: '%s'",
                              key_val);
@@ -280,6 +281,13 @@ SV *Py2Pl(PyObject * const obj) {
         return sv;
     }
 
+    /* a float */
+    else if (PyFloat_Check(obj)) {
+        SV * const sv = newSVnv(PyFloat_AsDouble(obj));
+        Printf(("Py2Pl: float\n"));
+        return sv;
+    }
+
     /* a function or method */
     else if (PyFunction_Check(obj) || PyMethod_Check(obj)) {
         SV * const inst_ptr = newSViv(0);
